==> nextcloud-28.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/fr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Lien public",
    "Photos" : "Photos",
    "On This Day" : "Ce même jour",
    "Your memories under your control" : "Gardez le contrôle de vos souvenirs",
    "All media" : "Tous les médias",
    "Videos" : "Vidéos",
    "Albums" : "Albums",
    "Collaborative albums" : "Albums collaboratifs",
    "People" : "Personnes",
    "Folders" : "Dossiers",
    "Favorites" : "Favoris",
    "On this day" : "Ce même jour",
    "Shared with you" : "Partagés avec vous",
    "Tags" : "Étiquettes",
    "Places" : "Lieux",
    "Map" : "Carte",
    "Photos settings" : "Paramètres de Photos",
    "Mark selection as favorite" : "Marquer la sélection comme favorite",
    "Add selection to favorites" : "Ajouter la sélection aux favoris",
    "Remove selection from favorites" : "Retirer la sélection des favoris",
    "Name of the album" : "Nom de l’album",
    "Location of the album" : "Emplacement de l’album",
    "Back" : "Retour",
    "Add collaborators" : "Ajouter des collaborateurs",
    "Save" : "Enregistrer",
    "Create album" : "Créer un album",
    "Add to Album" : "Ajouter à l’album",
    "Add selection to album {albumName}" : "Ajouter la sélection à l’album {albumName}",
    "Shared by" : "Partagé par",
    "Create a new album." : "Créer un nouvel album",
    "Create new album" : "Créer un nouvel album",
    "New album" : "Nouvel album",
    "_%n item_::_%n photos and videos_" : ["%n élément","%n photos et vidéos","%n photos et vidéos"],
    "Add people or groups who can edit your album" : "Ajoutez des personnes ou des groupes qui peuvent modifier votre album",
    "Search people or groups" : "Recherche des personnes ou des groupes",
    "No recommendations. Start typing." : "Pas de suggestion. Commencez à écrire.",
    "Group" : "Groupe",
    "Remove {collaboratorLabel} from the collaborators list" : "Supprimer {collaboratorLabel} de la liste des collaborateurs",
    "Copy the public link" : "Copier le lien public",
    "Public link copied!" : "Lien public copié !",
    "Copy public link" : "Copier le lien public",
    "Delete the public link" : "Supprimer le lien public",
    "Create public link share" : "Créer un partage par lien public",
    "Share via public link" : "Partager via un lien public",
    "Failed to fetch collaborators list." : "Échec de la récupération de la liste des collaborateurs.",
    "Failed to update album." : "Impossible de mettre à jour de l’album.",
    "This collection does not exist" : "Cette collection n’existe pas",
    "An error occurred" : "Une erreur est survenue",
    "No picture for this day" : "Aucune image ce jour",
    "Picture taken on this day will show up here." : "Les photos prises ce jour s’afficheront ici.",
    "More photos from this day" : "Plus de photos de cette journée",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n photo non assignée","%n photos non assignées","%n photos non assignées"],
    "Favorite" : "Favoris",
    "Select image {imageName}" : "Sélectionner l’image {imageName}",
    "Open the full size \"{name}\" image" : "Ouvrir l’image « {name} » dans sa taille originale",
    "Open the \"{name}\" folder" : "Ouvrir le dossier « {name} »",
    "Go back" : "Revenir en arrière",
    "Back to {folder}" : "Revenir au dossier {folder}",
    "Share this folder" : "Partager ce dossier",
    "Dates" : "Dates",
    "Jump to {date}" : "Aller au {date}",
    "Add to {destination}" : "Ajouter à {destination}",
    "There are no photos or videos yet!" : "Il n’y a pas encore de photos ou de vidéos !",
    "_{years} year ago_::_{years} years ago_" : ["Il y a {years} ans","Il y a {years} ans","Il y a {years} an(s)"],
    "Enable squared photos view" : "Activer l’affichage en miniatures carrées",
    "Delete source directory" : "Supprimer le dossier source",
    "All folders" : "Tous les dossiers",
    "Choose a different folder" : "Choisir un dossier différent ",
    "Select a source folder for your media" : "Sélectionner un dossier source pour vos médias",
    "Home" : "Personnel",
    "Choose default Photos upload and Albums location" : "Choisir l’emplacement par défaut pour le téléversement des photos et des albums",
    "Select the default upload location for your media" : "Sélectionnez l’emplacement de téléversement par défaut de vos médias",
    "View" : "Affichage",
    "Media folder" : "Dossier médias",
    "Choose the folders from where photos and videos are shown." : "Choisir les dossiers où les photos et vidéos seront affichées.",
    "Upload folder" : "Téléverser un dossier",
    "Choose the folder where photos and albums are uploaded to." : "Choisir le dossier où les photos et albums sont téléversés.",
    "_%n photo_::_%n photos_" : ["%n photo","%n photos","%n photos"],
    "Unselect all" : "Tout désélectionner",
    "Manage collaborators for this album" : "Gérer les collaborateurs pour cet album",
    "Open actions menu" : "Ouvrir le menu des actions",
    "Edit album details" : "Modifier les détails de l’album",
    "Download all files in album" : "Télécharger tous les fichiers de l’album",
    "Delete album" : "Supprimer l’album",
    "Download selected files" : "Télécharger les fichiers sélectionnés",
    "Remove selection from album" : "Retirer la sélection de l’album",
    "This album does not have any photos or videos yet!" : "Cet album n’a pas encore de photos ou de vidéos !",
    "Add photos to this album" : "Ajouter des photos à cet album",
    "Add photos to {albumName}" : "Ajouter des photos à {albumName}",
    "Manage collaborators" : "Gérer les collaborateurs",
    "Save collaborators for this album." : "Enregistrer les collaborateurs pour cet album.",
    "Cover photo for album {albumName}" : "Photo de couverture de l’album {albumName}",
    "There is no album yet!" : "Il n’y a pas encore d’album !",
    "This person could not be found" : "Cette personne n’a pas pu être trouvée",
    "Rename person" : "Renommer la personne",
    "Merge with different person" : "Fusionner avec une différente personne",
    "Download selected photos" : "Télécharger les photos sélectionnées",
    "Remove from favorites" : "Retirer des favoris",
    "Remove person" : "Retirer la personne",
    "Name of this person" : "Nom de cette personne",
    "Save." : "Enregistrer",
    "Merge person" : "Fusionner une personne",
    "Move to different person" : "Changer de personne",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Déplacer la photo vers une autre personne","Déplacer les photos vers une autre personne","Déplacer les photos vers une autre personne"],
    "_Remove photo from person_::_Remove photos from person_" : ["Supprimer la photo de la personne","Supprimer la photo de la personne","Supprimer les photos de la personne"],
    "This might take some time depending on the size of your photo library." : "Cela peut prendre un certain temps en fonction de la taille de votre photothèque.",
    "Recognized people will show up here" : "Les personnes reconnues apparaîtront ici",
    "This folder does not exist" : "Ce dossier n’existe pas",
    "Loading folders …" : "Chargement des dossiers ...",
    "No photos in here" : "Aucune photo",
    "Taken on {date} at {time}" : "Prise le {date} à {time}",
    "This place does not have any photos or videos yet!" : "Ce lieu n’a pas encore de photos ou de vidéos !",
    "Add photos to this place" : "Ajouter des photos à ce lieu",
    "Cover photo for place {placeName}" : "Photo de couverture pour le lieu {nom du lieu}",
    "There is no place yet!" : "Il n’y a pas encore de lieu !",
    "Cover photo for shared album {albumName}." : "Photo de couverture pour l’album partagé {albumName}.",
    "Back to tags overview" : "Retour à l’aperçu des étiquettes",
    "No photos with this tag yet" : "Pas de photo avec cette étiquette pour l’instant",
    "No tags yet" : "Aucune étiquette pour le moment",
    "Photos with tags will show up here" : "Les photos étiquetées apparaîtront ici",
    "Popular tags" : "Étiquettes populaires",
    "The source folder does not exists" : "Le dossier source n’existe pas",
    "Add" : "Ajouter",
    "Add to album" : "Ajouter à l’album",
    "Delete selection" : "Supprimer la sélection",
    "No photos or videos in here" : "Aucune photo ou vidéo ici",
    "Unassigned faces" : "Visages non attribués",
    "_%n photos_::_%n photos_" : ["%n photo","%n photos","%n photos"],
    "Failed to fetch collection." : "Échec de récupération de la collection.",
    "Failed to fetch collections list." : "La récupération de la liste des collections a échoué.",
    "Failed to fetch faces list." : "Échec de la récupération de la liste des visages.",
    "All your media" : "Tous vos médias",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Albums partagés",
    "Shared album {title}" : "Album partagé {title}",
    "Public album {title}" : "Album public {title}",
    "Tagged photos" : "Photos étiquetées ",
    "Tagged photo {title}" : "Photo étiquetée {title}",
    "{title}'s face" : "Visage de {title}",
    "{startDate} to {endDate}" : "{startDate} au {endDate}",
    "Details" : "Détails",
    "Failed to rename {oldName} to {faceName}." : "Échec du renommage de {oldName} en {faceName}.",
    "Failed to delete {faceName}." : "Échec de la suppression de {faceName}.",
    "Failed to delete {fileId}." : "Échec de la suppression de {fileId}.",
    "Failed to delete {fileName}." : "Échec de la suppression de {fileName}.",
    "Failed to set favorite state for {fileId}." : "Impossible de définir l’état des favoris pour {fileId}.",
    "Failed to set favorite state for {fileName}." : "Échec de la définition de l’état des favoris pour {fileName}.",
    "Could not load photos folder" : "Impossible de charger le dossier des photos",
    "Go back to the previous view." : "Revenir à la vue précédente",
    "Go to the add collaborators view." : "Allez à la vue d’ajout de collaborateurs",
    "Create the album." : "Créer l’album",
    "Back to the new album form." : "Retour au formulaire de nouvel album",
    "_Share with %n user_::_Share with %n users_" : ["Partager avec %n utilisateur","Partager avec %n utilisateurs","Partager avec %n utilisateurs"],
    "Search for collaborators" : "Rechercher des collaborateurs",
    "Add {collaboratorLabel} to the collaborators list" : "Ajouter {collaboratorLabel} à la liste des collaborateurs",
    "No collaborators available" : "Aucun collaborateur disponible",
    "Failed to fetch album." : "Impossible de récupérer l’album.",
    "The file is in the favorites" : "Le fichier se trouve dans les favoris",
    "Open the \"{name}\" sub-directory" : "Ouvrir le sous-dossier « {name} »",
    "Default Photos upload and Albums location" : "Emplacement par défaut du téléversement des photos et des albums",
    "Select the default location for your media" : "Sélectionnez l’emplacement par défaut de vos médias",
    "Invalid location selected" : "Emplacement sélectionné non valide",
    "Photos directory" : "Dossier des photos",
    "Add photos to the album" : "Ajouter des photos à l’album",
    "Failed to fetch albums list." : "Impossible de récupérer la liste des albums.",
    "Shared albums" : "Albums partagés",
    "Create a new album" : "Créer un nouvel album",
    "Add selection to an album" : "Ajouter la sélection à un album",
    "Failed to create {albumName}." : "Échec de la création de {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Échec du renommage de {currentAlbumName} en {newAlbumName}."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/fr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Lien public",
    "Photos" : "Photos",
    "On This Day" : "Ce même jour",
    "Your memories under your control" : "Gardez le contrôle de vos souvenirs",
    "All media" : "Tous les médias",
    "Videos" : "Vidéos",
    "Albums" : "Albums",
    "Collaborative albums" : "Albums collaboratifs",
    "People" : "Personnes",
    "Folders" : "Dossiers",
    "Favorites" : "Favoris",
    "On this day" : "Ce même jour",
    "Shared with you" : "Partagés avec vous",
    "Tags" : "Étiquettes",
    "Places" : "Lieux",
    "Map" : "Carte",
    "Photos settings" : "Paramètres de Photos",
    "Mark selection as favorite" : "Marquer la sélection comme favorite",
    "Add selection to favorites" : "Ajouter la sélection aux favoris",
    "Remove selection from favorites" : "Retirer la sélection des favoris",
    "Name of the album" : "Nom de l’album",
    "Location of the album" : "Emplacement de l’album",
    "Back" : "Retour",
    "Add collaborators" : "Ajouter des collaborateurs",
    "Save" : "Enregistrer",
    "Create album" : "Créer un album",
    "Add to Album" : "Ajouter à l’album",
    "Add selection to album {albumName}" : "Ajouter la sélection à l’album {albumName}",
    "Shared by" : "Partagé par",
    "Create a new album." : "Créer un nouvel album",
    "Create new album" : "Créer un nouvel album",
    "New album" : "Nouvel album",
    "_%n item_::_%n photos and videos_" : ["%n élément","%n photos et vidéos","%n photos et vidéos"],
    "Failed to fetch collaborators list." : "Échec de la récupération de la liste des collaborateurs.",
    "Failed to update album." : "Impossible de mettre à jour de l’album.",
    "Add people or groups who can edit your album" : "Ajoutez des personnes ou des groupes qui peuvent modifier votre album",
    "Search people or groups" : "Recherche des personnes ou des groupes",
    "No recommendations. Start typing." : "Pas de suggestion. Commencez à écrire.",
    "Group" : "Groupe",
    "Remove {collaboratorLabel} from the collaborators list" : "Supprimer {collaboratorLabel} de la liste des collaborateurs",
    "Copy the public link" : "Copier le lien public",
    "Public link copied!" : "Lien public copié !",
    "Copy public link" : "Copier le lien public",
    "Delete the public link" : "Supprimer le lien public",
    "Create public link share" : "Créer un partage par lien public",
    "Share via public link" : "Partager via un lien public",
    "This collection does not exist" : "Cette collection n’existe pas",
    "An error occurred" : "Une erreur est survenue",
    "No picture for this day" : "Aucune image ce jour",
    "Picture taken on this day will show up here." : "Les photos prises ce jour apparaîtront ici.",
    "More photos from this day" : "Plus de photos de cette journée",
    "_%n photos_::_%n photos_" : ["%n photo","%n photos","%n photos"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n photo non assignée","%n photos non assignées","%n photos non assignées"],
    "Favorite" : "Favoris",
    "Favorite image, open the full size \"{name}\" image" : "Image favorite, ouvrir dans sa taille originale",
    "Open the full size \"{name}\" image" : "Ouvrir l’image « {name} » dans sa taille originale",
    "Select image {imageName}" : "Sélectionner l’image {imageName}",
    "Open the \"{name}\" folder" : "Ouvrir le dossier « {name} »",
    "Go back" : "Revenir en arrière",
    "Date range" : "Plage de dates",
    "Select a date range" : "Sélectionner une plage de dates",
    "Select places" : "Sélectionner les lieux",
    "Dates" : "Dates",
    "Jump to specific date in list" : "Sauter à une date spécifique dans la liste",
    "Jump to {date}" : "Aller au {date}",
    "Add to {destination}" : "Ajouter à {destination}",
    "The destination folder is owned by {owner}" : "La destination du dossier appartient à {owner}",
    "There are no photos or videos yet!" : "Il n’y a pas encore de photos ou de vidéos !",
    "_{years} year ago_::_{years} years ago_" : ["Il y a {years} ans","Il y a {years} ans","Il y a {years} an(s)"],
    "Enable squared photos view" : "Activer l’affichage en miniatures carrées",
    "Delete source directory" : "Supprimer le dossier source",
    "Pick folder" : "Choisir un dossier",
    "Select a source folder for your media" : "Sélectionner un dossier source pour vos médias",
    "All folders" : "Tous les dossiers",
    "Add a Photos source for the timelines" : "Ajouter une source de Photos pour les chronologies",
    "Add folder" : "Ajouter un dossier",
    "Select the default upload location for your media" : "Sélectionnez l’emplacement de téléversement par défaut de vos médias",
    "Home" : "Personnel",
    "Choose default Photos upload and Albums location" : "Choisir l’emplacement par défaut pour le téléversement des photos et des albums",
    "Choose a different folder" : "Choisir un dossier différent ",
    "View" : "Affichage",
    "Media folders" : "Dossiers de médias",
    "Choose the folders from where photos and videos are shown." : "Sélectionnez les dossiers d'où proviennent les photos et les vidéos affichées.",
    "Upload folder" : "Dossier de téléversement",
    "Choose the folder where photos and albums are uploaded to." : "Choisir le dossier où les photos et albums sont téléversés.",
    "_%n photo_::_%n photos_" : ["%n photo","%n photos","%n photos"],
    "Unselect all" : "Tout désélectionner",
    "Toggle filter" : "Basculer le filtre",
    "Add photos to this album" : "Ajouter des photos à cet album",
    "Manage collaborators for this album" : "Gérer les collaborateurs pour cet album",
    "Open actions menu" : "Ouvrir le menu des actions",
    "Edit album details" : "Modifier les détails de l’album",
    "Download all files in album" : "Télécharger tous les fichiers de l’album",
    "Delete album" : "Supprimer l’album",
    "Download selected files" : "Télécharger les fichiers sélectionnés",
    "Remove selection from album" : "Retirer la sélection de l’album",
    "This album does not have any photos or videos yet!" : "Cet album n’a pas encore de photos ou de vidéos !",
    "Add photos to {albumName}" : "Ajouter des photos à {albumName}",
    "Manage collaborators" : "Gérer les collaborateurs",
    "Save collaborators for this album." : "Enregistrer les collaborateurs pour cet album.",
    "Cover photo for album {albumName}" : "Photo de couverture de l’album {albumName}",
    "There is no album yet!" : "Il n’y a pas encore d’album !",
    "This person could not be found" : "Cette personne n’a pas pu être trouvée",
    "Rename person" : "Renommer la personne",
    "Merge with different person" : "Fusionner avec une différente personne",
    "Download selected photos" : "Télécharger les photos sélectionnées",
    "Remove from favorites" : "Retirer des favoris",
    "Remove person" : "Retirer la personne",
    "Name of this person" : "Nom de cette personne",
    "Save." : "Enregistrer",
    "Merge person" : "Fusionner une personne",
    "Move to different person" : "Changer de personne",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Déplacer la photo vers une autre personne","Déplacer les photos vers une autre personne","Déplacer les photos vers une autre personne"],
    "_Remove photo from person_::_Remove photos from person_" : ["Supprimer la photo de la personne","Supprimer la photo de la personne","Supprimer les photos de la personne"],
    "This might take some time depending on the size of your photo library." : "Cela peut prendre un certain temps en fonction de la taille de votre photothèque.",
    "Recognized people will show up here" : "Les personnes reconnues apparaîtront ici",
    "This folder does not exist" : "Ce dossier n’existe pas",
    "Loading folders …" : "Chargement des dossiers ...",
    "No photos in here" : "Aucune photo",
    "Taken on {date} at {time}" : "Prise le {date} à {time}",
    "This place does not have any photos or videos yet!" : "Ce lieu n’a pas encore de photos ou de vidéos !",
    "Add photos to this place" : "Ajouter des photos à ce lieu",
    "Cover photo for place {placeName}" : "Photo de couverture pour le lieu {placeName}",
    "There is no place yet!" : "Il n’y a pas encore de lieu !",
    "Cover photo for shared album {albumName}" : "Photo de couverture pour l’album partagé {albumName}.",
    "Back to tags overview" : "Retour à l’aperçu des étiquettes",
    "No photos with this tag yet" : "Pas de photo avec cette étiquette pour l’instant",
    "No tags yet" : "Aucune étiquette pour le moment",
    "Photos with tags will show up here" : "Les photos étiquetées apparaîtront ici",
    "Popular tags" : "Étiquettes populaires",
    "All tags" : "Toutes les étiquettes",
    "Create new album from filters" : "Créer un nouvel album à partir des filtres",
    "One of the source folders does not exist" : "L'un des dossiers source n'existe pas",
    "Add to album" : "Ajouter à l’album",
    "Delete selection" : "Supprimer la sélection",
    "No photos or videos in here" : "Aucune photo ou vidéo ici",
    "Unassigned faces" : "Visages non attribués",
    "Failed to fetch collection." : "Échec de récupération de la collection.",
    "Failed to fetch collections list." : "La récupération de la liste des collections a échoué.",
    "Failed to fetch faces list." : "Échec de la récupération de la liste des visages.",
    "Error fetching files" : "Erreur dans la récupération des fichiers",
    "All your media" : "Tous vos médias",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Albums partagés",
    "Shared album {title}" : "Album partagé {title}",
    "Public album {title}" : "Album public {title}",
    "Tagged photos" : "Photos étiquetées ",
    "Tagged photo {title}" : "Photo étiquetée {title}",
    "{title}'s face" : "Visage de {title}",
    "{startDate} to {endDate}" : "{startDate} au {endDate}",
    "Details" : "Détails",
    "Failed to delete {fileBaseName}" : "Échec de la suppression de {fileBaseName}.",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Échec du renommage de {currentCollectionFileName} en {newCollectionFileName}.",
    "Failed to delete {collectionFileName}" : "Échec de la suppression de {collectionFileName}.",
    "Failed to remove {fileBaseName}" : "Échec de la suppression de {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Échec du renommage de {oldName} en {faceName}.",
    "Failed to delete {faceName}" : "Échec de la suppression de {faceName}.",
    "Failed to delete {fileId}" : "Échec de la suppression de {fileId}.",
    "Failed to delete {fileName}" : "Échec de la suppression de {fileName}.",
    "Failed to set favorite state for {fileId}" : "Impossible de définir l’état des favoris pour {fileId}.",
    "Failed to set favorite state for {fileName}" : "Impossible de définir l’état des favoris pour {fileName}.",
    "Could not load photos folder" : "Impossible de charger le dossier des photos",
    "Back to {folder}" : "Revenir au dossier {folder}",
    "Share this folder" : "Partager ce dossier",
    "One of the source folders does not exists" : "L’un des dossiers source n’existe pas",
    "Add" : "Ajouter"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
